==> java-runtime-7.0.23-sources.jar: java/lang/IllegalArgumentException.java <==
/*
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores
 * CA 94065 USA or visit www.oracle.com if you need additional information or
 * have any questions.
 */
package java.lang;
/**
 * Thrown to indicate that a method has been passed an illegal or inappropriate argument.
 * Since: JDK1.0, CLDC 1.0 See Also:Thread.setPriority(int)
 */
public class IllegalArgumentException extends java.lang.RuntimeException{
    /**
     * Constructs an IllegalArgumentException with no detail message.
     */
    public IllegalArgumentException(){
         //TODO codavaj!!
    }

    /**
     * Constructs an IllegalArgumentException with the specified detail message.
     * s - the detail message.
     */
    public IllegalArgumentException(java.lang.String s){
         //TODO codavaj!!
    }

}

==> java-runtime-7.0.221-sources.jar: java/lang/IllegalArgumentException.java <==
/*
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores
 * CA 94065 USA or visit www.oracle.com if you need additional information or
 * have any questions.
 */
package java.lang;
/**
 * Thrown to indicate that a method has been passed an illegal or inappropriate argument.
 * Since: JDK1.0, CLDC 1.0 See Also:Thread.setPriority(int)
 */
public class IllegalArgumentException extends java.lang.RuntimeException{
    /**
     * Constructs an IllegalArgumentException with no detail message.
     */
    public IllegalArgumentException(){
         //TODO codavaj!!
    }

    /**
     * Constructs an IllegalArgumentException with the specified detail message.
     * s - the detail message.
     */
    public IllegalArgumentException(java.lang.String s){
         //TODO codavaj!!
    }

    /**
     * Constructs an IllegalArgumentException with the specified detail message and cause.
     * s - the detail message.
     * cause - the cause.
     */
    public IllegalArgumentException(java.lang.String s, java.lang.Throwable cause) {
         //TODO codavaj!!
    }

    /**
     * Constructs an IllegalArgumentException with the specified cause.
     * cause - the cause.
     */
    public IllegalArgumentException(java.lang.Throwable cause) {
         //TODO codavaj!!
    }
}
